summaryrefslogtreecommitdiff
path: root/scripts/version.sh
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2013-04-06 13:14:45 +0200
committerPaul Buetow <paul@buetow.org>2013-04-06 13:14:45 +0200
commit5f4e214740242513c837c8a005ca23779bab1d0c (patch)
tree3880f745b0d3376030e3342e60679f25b38bdc4c /scripts/version.sh
parent23c5e7d57e1e9216f4da3446656df2dc7202975d (diff)
tagging ychat-0.8.2ychat-0.8.2
Diffstat (limited to 'scripts/version.sh')
-rwxr-xr-xscripts/version.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/version.sh b/scripts/version.sh
index 50c189c..46b9fc5 100755
--- a/scripts/version.sh
+++ b/scripts/version.sh
@@ -1,11 +1,11 @@
#!/bin/sh
# The yhttpd Project (2005)
#
# This script shows yhttpd VERSION-BRANCH Build BUILDNUMBER
version=`grep VERSION src/msgs.h | head -n 1 | cut -d'"' -f2`
branch=`grep BRANCH src/msgs.h | head -n 1 | cut -d'"' -f2`
build=`grep BUILD src/msgs.h | tail -n 1 | cut -d' ' -f3`
-echo "yhttpd $version-$branch Build $build"
+echo "yChat $version-$branch Build $build"
@@ -1,11 +1,11 @@
#!/bin/sh
-# The yhttpd Project (2005)
+# The yChat Project (2005)
#
@@ -1,11 +1,11 @@
#
-# This script shows yhttpd VERSION-BRANCH Build BUILDNUMBER
+# This script shows yChat VERSION-BRANCH Build BUILDNUMBER
version=`grep VERSION src/msgs.h | head -n 1 | cut -d'"' -f2`
branch=`grep BRANCH src/msgs.h | head -n 1 | cut -d'"' -f2`